"""sumologic-opentelemetry - An all-in-one package

An all-in-one package for python projects used to enable OpenTelemetry auto-instrumentation"""

from . import env  # noqa

__version__ = "1.9.1"
__author__ = "Sumo Logic Authors <support@sumologic.com>"
__all__ = []
